#ifndef XMEM_CONFIG_H_
#define XMEM_CONFIG_H_

#define XPAR_AXI_NOC2_DDR_LOW_0_BASEADDR 0x100000
#define XPAR_AXI_NOC2_DDR_LOW_0_HIGHADDR 0x7fffffff
#define XPAR_OCM_RAM_0_BASEADDRESS 0xbbf00000
#define XPAR_OCM_RAM_0_HIGHADDRESS 0xbbf7ffff
#define XPAR_OCM_RAM_1_BASEADDRESS 0xbbf80000
#define XPAR_OCM_RAM_1_HIGHADDRESS 0xbbffffff
#define XPAR_OCM_RAM_2_BASEADDRESS 0xbbe00000
#define XPAR_OCM_RAM_2_HIGHADDRESS 0xbbe7ffff
#define XPAR_OCM_RAM_3_BASEADDRESS 0xbbe80000
#define XPAR_OCM_RAM_3_HIGHADDRESS 0xbbefffff

#endif