#include "xcortexr52.h"

XCortexr52_Config XCortexr52_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {
	{
		0x5f5dd19,  /* xlnx,timestamp-clk-freq */
		0x34274ea8,  /* cpu-frequency */
		0x1  /* reg */
	}
};